JsonUtil class

JSON utilities exposed as static methods.

Deprecated — use the equivalent top-level functions instead: castAsJsonObjectArray, jsonGet.

Annotations
  • @Deprecated('Use top-level castAsJsonObjectArray and jsonGet functions')

Constructors

JsonUtil()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

castAsCollection(JsonValue? value) JsonCollection
get(JsonObject object, dynamic path) JsonValue?